@@ -4,19 +4,18 @@ import mailbox
 import os.path
 import sys
 from datetime import datetime
-from email import message_from_file
+from email import message_from_file, message_from_string
 from email.message import EmailMessage
 from io import StringIO
 from traceback import format_exc
 from unittest import SkipTest, expectedFailure
+from unittest.mock import Mock, patch
 
 from django.conf import settings
 from django.core.management import call_command
 from django.db import DEFAULT_DB_ALIAS
 from django.utils.timezone import utc
 
-from mock import Mock, patch
-
 from hyperkitty.lib.incoming import add_to_list
 from hyperkitty.management.commands.hyperkitty_import import Command
 from hyperkitty.models import Email, MailingList
@@ -141,6 +140,7 @@ class CommandTestCase(TestCase):
         msg2 = EmailMessage()
         msg2["From"] = "dummy@example.com"
         msg2["Date"] = "01 Feb 2015 12:00:00"
+        msg2["Message-ID"] = ''
         msg2.set_payload("msg2")
         mbox = mailbox.mbox(os.path.join(self.tmpdir, "test.mbox"))
         mbox.add(msg)
@@ -155,6 +155,31 @@ class CommandTestCase(TestCase):
         # Both messages should be archived.
         self.assertEqual(Email.objects.count(), 2)
 
+    def test_wierd_message_id(self):
+        # Message-IDs like this have been seen.
+        msg = message_from_string("""\
+From: dummy@example.com
+Date: 01 Feb 2015 12:00:00
+Message-ID: <58482FD7034976FE@example.com> (added by
+ postmaster@example.com)
+
+msg1
+""", EmailMessage)
+        mbox = mailbox.mbox(os.path.join(self.tmpdir, "test.mbox"))
+        mbox.add(msg)
+        mbox.close()
+        # do the import
+        output = StringIO()
+        kw = self.common_cmd_args.copy()
+        kw["stdout"] = kw["stderr"] = output
+        call_command('hyperkitty_import',
+                     os.path.join(self.tmpdir, "test.mbox"), **kw)
+        # The message should be archived.
+        self.assertEqual(Email.objects.count(), 1)
+        # Its Message-ID should be clean
+        archived_mid = Email.objects.get().as_message()['message-id']
+        self.assertEqual(archived_mid, '<58482FD7034976FE@example.com>')
+
     def test_wrong_encoding(self):
         """badly encoded message, only fails on PostgreSQL"""
         db_engine = settings.DATABASES[DEFAULT_DB_ALIAS]["ENGINE"]
@@ -200,10 +225,15 @@ class CommandTestCase(TestCase):
         # The message should be archived.
         self.assertEqual(Email.objects.count(), 1)
         # But there should be an error message.
-        self.assertIn("Can't get date header in message", output.getvalue())
+        if sys.hexversion < 0x30a0000:
+            self.assertIn("Can't get date header in message",
+                          output.getvalue())
+        else:
+            self.assertIn("Bad datetime in date header in message",
+                          output.getvalue())
 
     def test_no_date_but_resent_date(self):
-        # If there's no Dete: header, fall back to Resent-Date:.
+        # If there's no Date: header, fall back to Resent-Date:.
         with open(get_test_file("resent-date.txt")) as email_file:
             msg = message_from_file(email_file)
         mbox = mailbox.mbox(os.path.join(self.tmpdir, "test.mbox"))
@@ -258,7 +288,7 @@ class CommandTestCase(TestCase):
                      os.path.join(self.tmpdir, "test.mbox"), **kw)
         # The message should be archived.
         self.assertEqual(Email.objects.count(), 1)
-        # The archived_date should be Dec  1 00:56:19 1999 1999
+        # The archived_date should be Dec  1 00:56:19 1999.
         self.assertEqual(Email.objects.all()[0].date,
                          datetime(1999, 12, 1, 0, 56, 19, tzinfo=utc))
 
@@ -333,6 +363,11 @@ class CommandTestCase(TestCase):
 
     def test_unconvertable_message(self):
         # This message can't be converted to an email.message.EmailMessage.
+        # This fails with Python 3.9 >=3.9.13 and versions >= 3.10.5 because
+        # https://bugs.python.org/issue43323 is fixed.
+        if ((sys.hexversion >= 0x3090df0 and sys.hexversion < 0x30a0000) or
+                sys.hexversion >= 0x30a05f0):
+            raise SkipTest
         mbox = mailbox.mbox(os.path.join(self.tmpdir, "test.mbox"))
         # We have to do it this way to see the exception.
         with open(get_test_file("unconvertable_message.txt"), "rb") as em_file:
