@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2014-2019 by the Free Software Foundation, Inc.
+# Copyright (C) 2014-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of HyperKitty.
 #
@@ -25,13 +25,12 @@ import os
 from email import message_from_file
 from email.message import EmailMessage
 from email.policy import default
+from unittest.mock import Mock, patch
 
 from django.core.cache import cache
 from django.db import DataError, IntegrityError
 from django.utils import timezone
 
-import mock
-
 from hyperkitty.lib.incoming import DuplicateMessage, add_to_list
 from hyperkitty.lib.utils import get_message_id_hash
 from hyperkitty.models import Attachment, Email, MailingList, Thread
@@ -192,6 +191,22 @@ class TestAddToList(TestCase):
             self.fail(e)
         self.assertEqual(Attachment.objects.count(), 1)
 
+    def test_non_ascii_text_attachment_declared_as_ascii(self):
+        # Some defective mail has a text attachment declared as ascii but
+        # containing non-ascii. We should just replace the non-ascii character.
+        with open(get_test_file("attachment-4.txt")) as email_file:
+            msg = message_from_file(email_file, EmailMessage, policy=default)
+        try:
+            add_to_list("example-list", msg)
+        except Exception as e:
+            self.fail(e)
+        self.assertEqual(Attachment.objects.count(), 1)
+        self.assertEqual(Attachment.objects.all()[0].content,
+                         b'All votes are reported in the form "*Y-N-A*" '
+                         b'(*in favor-Y???opposed-N???abstentions-A*; e.g. '
+                         b'"5-1-2" means "5 in favor, 1 opposed, and 2 '
+                         b'abstentions").\n')
+
     def test_attachment_local_storage(self):
         # The HYPERKITTY_ATTACHMENT_FOLDER config allows usage of a local
         # folder for attachments.
@@ -531,11 +546,11 @@ class TestAddToList(TestCase):
         msg["Message-ID"] = "<dummy>"
         msg["Date"] = "Fri, 02 Nov 2012 16:07:54"
         msg.set_payload("Fake Message")
-        email = mock.Mock()
+        email = Mock()
         email.save.side_effect = DataError("test error")
-        with mock.patch("hyperkitty.lib.incoming.Email") as Email:
+        with patch("hyperkitty.lib.incoming.Email") as Email:
             Email.return_value = email
-            filter_mock = mock.Mock()
+            filter_mock = Mock()
             filter_mock.exists.return_value = False
             Email.objects.filter.return_value = filter_mock
             self.assertRaises(ValueError, add_to_list, "example-list", msg)
