@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2012-2019 by the Free Software Foundation, Inc.
+# Copyright (C) 2012-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of HyperKitty.
 #
@@ -21,10 +21,12 @@
 This file is the main URL config for a Django website including HyperKitty.
 """
 
-from django.conf.urls import include, url
+from django.conf.urls import include
+from django.urls import path
+
 
 urlpatterns = [
-    url(r'', include('hyperkitty.urls')),
-    url(r'', include('django_mailman3.urls')),
-    url(r'^accounts/', include('allauth.urls')),
+    path('', include('hyperkitty.urls')),
+    path('', include('django_mailman3.urls')),
+    path('accounts/', include('allauth.urls')),
 ]
