@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2016-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2016-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of HyperKitty.
 #
@@ -23,11 +23,11 @@
 import json
 from email.message import EmailMessage
 from io import BytesIO
+from unittest.mock import patch
 
 from django.conf import settings
 from django.contrib.sites.models import Site
 
-import mock
 from django_mailman3.models import MailDomain
 
 from hyperkitty.models.email import Email
@@ -73,10 +73,10 @@ class ArchiveTestCase(TestCase):
         msg["Date"] = "Fri, 02 Nov 2012 16:07:54"
         msg.set_payload("Fake Message")
         self.message = BytesIO(msg.as_string().encode("utf-8"))
-        self.url = "{}?key={}".format(
-            reverse('hk_mailman_archive'),
-            settings.MAILMAN_ARCHIVER_KEY,
-        )
+        # Pass archiver key using Authorization HTTP header
+        self.auth = {
+            'HTTP_AUTHORIZATION': f'Token {settings.MAILMAN_ARCHIVER_KEY}'}
+        self.url = reverse('hk_mailman_archive')
 
     def test_basic(self):
         response = self.client.post(
@@ -85,9 +85,10 @@ class ArchiveTestCase(TestCase):
                 "mlist": "list@example.com",
                 "name": "email.txt",
                 "message": self.message,
-            }
+            },
+            **self.auth,
         )
-        self.assertEqual(response.status_code, 200)
+        self.assertEqual(response.status_code, 200, response.content.decode())
         result = json.loads(response.content.decode(response.charset))
         self.assertEqual(result, {
             "url": "https://example.com/list/list@example.com/message/"
@@ -96,7 +97,7 @@ class ArchiveTestCase(TestCase):
         self.assertEqual(Email.objects.filter(message_id="dummy").count(), 1)
 
     def test_data_error(self):
-        with mock.patch("hyperkitty.views.mailman.add_to_list") as atl:
+        with patch("hyperkitty.views.mailman.add_to_list") as atl:
             atl.side_effect = ValueError("test error")
             response = self.client.post(
                 self.url,
@@ -104,10 +105,59 @@ class ArchiveTestCase(TestCase):
                     "mlist": "list@example.com",
                     "name": "email.txt",
                     "message": self.message,
-                }
+                },
+                **self.auth
             )
-        self.assertEqual(response.status_code, 400)
+        self.assertEqual(response.status_code, 400, response.content.decode())
         result = json.loads(response.content.decode(response.charset))
         self.assertEqual(result, {
             "error": "test error",
         })
+
+    def test_missing_auth(self):
+        response = self.client.post(
+            self.url,
+            data={
+                'mlist': 'list@example.com',
+                'name': 'email.txt',
+                'message': self.message,
+            },
+        )
+        self.assertContains(
+            response,
+            'The archiver key must be',
+            status_code=401,
+            )
+
+    def test_wrong_auth(self):
+        response = self.client.post(
+            self.url,
+            data={
+                'mlist': 'list@example.com',
+                'name': 'email.txt',
+                'message': self.message,
+            },
+            HTTP_AUTHORIZATION='Token IncorrectArchiverKey'
+        )
+        self.assertContains(
+            response,
+            'the MAILMAN_ARCHIVER_KEY is provided by you and it is correct',
+            status_code=401,
+            )
+
+    def test_old_auth(self):
+        """Sending key as a GET param tells you to upgrade
+        mailman-hyperkitty"""
+        response = self.client.post(
+            self.url + '?key=foo',
+            data={
+                'mlist': 'list@example.com',
+                'name': 'email.txt',
+                'message': self.message,
+            },
+        )
+        self.assertContains(
+            response,
+            'You need to upgrade the mailman-hyperkitty package',
+            status_code=401,
+            )
