@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2012-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2012-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of HyperKitty.
 #
@@ -27,6 +27,7 @@ import uuid
 from email import message_from_file
 from email.message import EmailMessage
 from email.policy import default
+from unittest.mock import Mock, patch
 
 from django.contrib.auth.models import User
 from django.core import mail
@@ -36,12 +37,11 @@ from django.utils import timezone
 from allauth.account.models import EmailAddress
 from django_gravatar.helpers import get_gravatar_url
 from django_mailman3.tests.utils import get_flash_messages
-from mock import Mock, patch
 
 from hyperkitty.lib.incoming import add_to_list
 from hyperkitty.lib.utils import get_message_id_hash
 from hyperkitty.models.email import Attachment, Email
-from hyperkitty.models.mailinglist import MailingList
+from hyperkitty.models.mailinglist import ArchiveRenderingMode, MailingList
 from hyperkitty.models.thread import Thread
 from hyperkitty.tests.utils import TestCase, get_test_file
 from hyperkitty.utils import reverse
@@ -339,19 +339,6 @@ class MessageViewsTestCase(TestCase):
         response2 = self.client.get(url2)
         self.assertContains(response2, "email-body fixed", status_code=200)
 
-    def test_email_escaped_body(self):
-        msg = EmailMessage()
-        msg["From"] = "Dummy Sender <dummy@example.com>"
-        msg["Subject"] = "Dummy Subject"
-        msg["Date"] = "Mon, 02 Feb 2015 13:00:00 +0300"
-        msg["Message-ID"] = "<msg2>"
-        msg.set_payload("Email address: email@example.com")
-        add_to_list("list@example.com", msg)
-        url = reverse('hk_message_index', args=("list@example.com",
-                      get_message_id_hash("msg2")))
-        response = self.client.get(url)
-        self.assertNotContains(response, "email@example.com", status_code=200)
-
     def test_email_in_link_in_body(self):
         msg = EmailMessage()
         msg["From"] = "Dummy Sender <dummy@example.com>"
@@ -365,7 +352,8 @@ class MessageViewsTestCase(TestCase):
                       get_message_id_hash("msg2")))
         response = self.client.get(url)
         self.assertContains(
-            response, '<a href="{0}" rel="nofollow">{0}</a>'.format(link),
+            response,
+            '<a target="_blank" href="{}">http://example.com/list/email@example.com/message</a>'.format(link),   # noqa: E501
             status_code=200)
 
     def test_email_escaped_sender(self):
@@ -382,6 +370,32 @@ class MessageViewsTestCase(TestCase):
         self.assertNotContains(
             response, "someone-else@example.com", status_code=200)
 
+    def test_email_rendered_using_rendering_mode(self):
+        # Test that MailingList's archive_rendering_mode determines if the text
+        # is rendered as plaintext or not.
+        msg = EmailMessage()
+        msg["From"] = "someone-else@example.com"
+        msg["Subject"] = "Dummy Subject"
+        msg["Date"] = "Mon, 02 Feb 2015 13:00:00 +0300"
+        msg["Message-ID"] = "<msg2>"
+        msg.set_payload("**Dummy content**")
+        add_to_list("list@example.com", msg)
+        mlist = MailingList.objects.get(name="list@example.com")
+        mlist.archive_rendering_mode = ArchiveRenderingMode.text.name
+        mlist.save()
+        url = reverse('hk_message_index', args=("list@example.com",
+                      get_message_id_hash("msg2")))
+        response = self.client.get(url)
+        self.assertContains(response,
+                            "<p>**Dummy content**</p>",
+                            status_code=200)
+        mlist.archive_rendering_mode = ArchiveRenderingMode.markdown.name
+        mlist.save()
+        response = self.client.get(url)
+        self.assertContains(response,
+                            "<strong>**Dummy content**</strong>",
+                            status_code=200)
+
     def test_delete_forbidden(self):
         url = reverse('hk_message_delete', args=("list@example.com",
                       get_message_id_hash("msg")))
@@ -518,7 +532,10 @@ class MessageViewsTestCase(TestCase):
             email=msg, counter=1, name="testattach.txt",
             content_type="text/plain", encoding="ascii",
         )
-        att.set_content("test_content")
+        contents = "test_content"
+        # Don't set the attachment object's content so we get it from the fs,
+        # but do set it's size.
+        att.size = len(contents)
         att.save()
         # Create the attachment on the filesystem
         attachment_folder = os.path.join(self.tmpdir, "attachments")
@@ -527,7 +544,6 @@ class MessageViewsTestCase(TestCase):
             str(msg.id),
         )
         os.makedirs(filedir)
-        contents = "test content"
         with open(os.path.join(filedir, "1"), "w") as f:
             f.write(contents)
         # Now get it.
