@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2012-2019 by the Free Software Foundation, Inc.
+# Copyright (C) 2012-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of HyperKitty.
 #
@@ -21,12 +21,12 @@
 
 import uuid
 from email.message import EmailMessage
+from unittest.mock import Mock, patch
 
 from django.contrib.auth.models import User
 
 from django_mailman3.tests.utils import FakeMMList, FakeMMMember
 from haystack import DEFAULT_ALIAS
-from mock import Mock, patch
 
 from hyperkitty.lib.incoming import add_to_list
 from hyperkitty.models import ArchivePolicy, MailingList
